@@ -909,7 +909,6 @@ class TasksAssignResource(Resource, ArgsMixin):
             200:
                 description: Given tasks lists assigned to given person
         """
-        user_service.check_person_is_not_bot(person_id)
         args = self.get_args(
             [
                 {
@@ -925,11 +924,14 @@ class TasksAssignResource(Resource, ArgsMixin):
         current_user = persons_service.get_current_user()
         for task_id in args["task_ids"]:
             try:
+                user_service.check_person_is_not_bot(person_id)
                 user_service.check_task_departement_access(task_id, person_id)
-                task = self.assign_task(task_id, person_id, current_user["id"])
-                notifications_service.create_assignation_notification(
+                task = tasks_service.assign_task(
                     task_id, person_id, current_user["id"]
                 )
+                notifications_service.create_assignation_notification(
+                    task_id, person_id
+                )
                 tasks.append(task)
             except TaskNotFoundException:
                 pass
@@ -942,9 +944,6 @@ class TasksAssignResource(Resource, ArgsMixin):
 
         return tasks
 
-    def assign_task(self, task_id, person_id, assigner_id):
-        return tasks_service.assign_task(task_id, person_id, assigner_id)
-
 
 class TaskAssignResource(Resource, ArgsMixin):
     """
@@ -993,11 +992,13 @@ class TaskAssignResource(Resource, ArgsMixin):
             ]
         )
         person_id = args["person_id"]
+        current_user = persons_service.get_current_user()
         try:
             user_service.check_person_is_not_bot(person_id)
-            task = tasks_service.get_task(task_id)
             user_service.check_task_departement_access(task_id, person_id)
-            self.assign_task(task_id, person_id)
+            task = tasks_service.assign_task(
+                task_id, person_id, current_user["id"]
+            )
             notifications_service.create_assignation_notification(
                 task_id, person_id
             )
@@ -1007,9 +1008,6 @@ class TaskAssignResource(Resource, ArgsMixin):
 
         return task
 
-    def assign_task(self, task_id, person_id):
-        return tasks_service.assign_task(task_id, person_id)
-
 
 class TaskFullResource(Resource):
     """
@@ -1739,3 +1737,23 @@ class OpenTasksResource(Resource, ArgsMixin):
             page=args["page"],
             limit=args["limit"],
         )
+
+
+
+class OpenTasksStatsResource(Resource, ArgsMixin):
+
+    @jwt_required()
+    def get(self):
+        """
+        Return task amount, task done amount, total estimation, total duration
+        by status by task type by project for open projects. It aggregates the
+        result at the project level.
+        ---
+        tags:
+        - Tasks
+        responses:
+            200:
+                description: A dict organized by project that contains
+                the results for each task type and status pairs.
+        """
+        return tasks_service.get_open_tasks_stats()
\ No newline at end of file
