@@ -31,7 +31,7 @@ from zou.app.models.task import Task
 from zou.app.models.time_spent import TimeSpent
 from zou.app.models.working_file import WorkingFile
 
-from zou.app.utils import events, fields
+from zou.app.utils import events, fields, date_helpers
 from zou.app.stores import file_store
 from zou.app import config
 
@@ -442,9 +442,9 @@ def remove_old_events(days_old=90):
     """
     Remove events older than *days_old*.
     """
-    limit_date = datetime.datetime.now(
-        datetime.timezone.utc
-    ) - datetime.timedelta(days=days_old)
+    limit_date = date_helpers.get_utc_now_datetime() - datetime.timedelta(
+        days=days_old
+    )
     ApiEvent.query.filter(ApiEvent.created_at < limit_date).delete()
     ApiEvent.commit()
 
@@ -453,9 +453,9 @@ def remove_old_login_logs(days_old=90):
     """
     Remove login logs older than *days_old*.
     """
-    limit_date = datetime.datetime.now(
-        datetime.timezone.utc
-    ) - datetime.timedelta(days=days_old)
+    limit_date = date_helpers.get_utc_now_datetime() - datetime.timedelta(
+        days=days_old
+    )
     LoginLog.query.filter(LoginLog.created_at < limit_date).delete()
     LoginLog.commit()
 
@@ -464,9 +464,9 @@ def remove_old_notifications(days_old=90):
     """
     Remove notifications older than *days_old*.
     """
-    limit_date = datetime.datetime.now(
-        datetime.timezone.utc
-    ) - datetime.timedelta(days=days_old)
+    limit_date = date_helpers.get_utc_now_datetime() - datetime.timedelta(
+        days=days_old
+    )
     Notification.query.filter(Notification.created_at < limit_date).delete()
     Notification.commit()
 
